@@ -1,5 +1,6 @@
 class ClickMailer < ApplicationMailer
   track click: true, except: [:welcome]
+  track click: -> { @track }, only: [:conditional]
 
   def welcome
     mail_html('<a href="https://example.org">Test</a>')
@@ -9,6 +10,10 @@ class ClickMailer < ApplicationMailer
     mail_html('<a href="https://example.org">Test</a>')
   end
 
+  def query_params
+    mail_html('<a href="https://example.org?a=1&b=2">Test</a>')
+  end
+
   def mailto
     mail_html('<a href="mailto:hi@example.org">Test</a>')
   end
@@ -20,4 +25,9 @@ class ClickMailer < ApplicationMailer
   def schemeless
     mail_html('<a href="example.org">Test</a>')
   end
+
+  def conditional(track)
+    @track = track
+    mail_html('<a href="https://example.org">Test</a>')
+  end
 end
