@@ -2,7 +2,7 @@ class MessageMailer < ApplicationMailer
   track message: false, only: [:other]
   track message: true, only: [:other2]
 
-  after_action :prevent_delivery
+  after_action :prevent_delivery, only: [:no_deliver]
 
   def welcome
     mail
@@ -17,13 +17,12 @@ class MessageMailer < ApplicationMailer
   end
 
   def no_deliver
-    @prevent_delivery = true
     mail
   end
 
   private
 
   def prevent_delivery
-    mail.perform_deliveries = false if @prevent_delivery
+    mail.perform_deliveries = false
   end
 end
