@@ -4,7 +4,12 @@ ActiveRecord::Schema.define do
     t.text :to
     t.string :mailer
     t.text :subject
-    t.timestamp :sent_at
+    t.datetime :sent_at
+
+    # opens & clicks
+    t.string :token
+    t.datetime :opened_at
+    t.datetime :clicked_at
 
     # extra
     t.integer :coupon_id
