@@ -4,17 +4,32 @@ Bundler.require(:default)
 require "minitest/autorun"
 require "minitest/pride"
 
+AhoyEmail.api = true
+
 Combustion.path = "test/internal"
 Combustion.initialize! :active_record, :action_mailer do
   if ActiveRecord::VERSION::MAJOR < 6 && config.active_record.sqlite3.respond_to?(:represent_boolean_as_integer)
     config.active_record.sqlite3.represent_boolean_as_integer = true
   end
+
+  logger = ActiveSupport::Logger.new(ENV["VERBOSE"] ? STDOUT : nil)
+  config.logger = logger
 end
 
 require_relative "support/mongoid" if defined?(Mongoid)
 
 ActionMailer::Base.delivery_method = :test
 
+class EmailSubscriber
+  def open(event)
+    $open_events << event
+  end
+
+  def click(event)
+    $click_events << event
+  end
+end
+
 class Minitest::Test
   def setup
     Ahoy::Message.delete_all
@@ -45,4 +60,16 @@ class Minitest::Test
       AhoyEmail.default_options = previous_options
     end
   end
+
+  def with_subscriber(subscriber)
+    previous_subscribers = AhoyEmail.subscribers
+    begin
+      $open_events = []
+      $click_events = []
+      AhoyEmail.subscribers = [subscriber]
+      yield
+    ensure
+      AhoyEmail.subscribers = previous_subscribers
+    end
+  end
 end
